@@ -176,12 +176,12 @@ class GitHandler:
                 stdout=subprocess.PIPE,
             )
 
-            return (
-                output.stdout.decode("utf-8")
-                .strip("\n")
-                .strip()
-                .removeprefix("origin/")
-            )
+            result = output.stdout.decode("utf-8").strip("\n").strip()
+
+            if result.startswith("origin/"):
+                return result[7:]
+            return result
+
         except CalledProcessError:
             return ""
 
